@@ -68,11 +68,29 @@ class DroneHandler:
         except Exception:
             return None
 
+    def get_repo_build(self, repo, build_number):
+        build = requests.get(
+            f"{BASEURL}/api/repos/primait/{repo}/builds/{build_number}",
+            headers={"Authorization": f"Bearer {self._token}"},
+        ).json()
+
+        return build
+
     def get_build_url(self, build_number):
         if build_number:
             return f"{BASEURL}/primait/{self._repo}/{build_number}"
         return None
 
+    def get_repo_build_url(self, repo, build_number):
+        if build_number:
+            return f"{BASEURL}/primait/{repo}/{build_number}"
+        return None
+
+    def get_build_and_pipeline_url(self, repo, build_number, pipeline_number):
+        if build_number:
+            return f"{BASEURL}/primait/{repo}/{build_number}/{pipeline_number}"
+        return None
+
     def get_tags_from_builds(self):
         tags = []
         builds = requests.get(
